/*
 *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#ifndef _DRAGNDROP_H
#define _DRAGNDROP_H

#include "wxMaxima.h"

#if wxUSE_DRAG_AND_DROP

enum {
  DND_LOAD,
  DND_WRITE
};

class FileDrop : public wxFileDropTarget
{
 public:
  FileDrop(wxMaxima *parent)
    { wxmax = parent; }
  ~FileDrop() {};
  bool OnDropFiles(wxCoord x, wxCoord y, const wxArrayString& files);
 protected:
  wxMaxima *wxmax;
};

#endif

#endif
